@@ -12,7 +12,7 @@
 #' @importFrom normaliseR normalise
 #' @param x \code{feature_calculations} object containing the raw feature matrix produced by \code{theft::calculate_features}
 #' @param type \code{character} specifying the type of plot to draw. Defaults to \code{"quality"}
-#' @param norm_method \code{character} specifying a rescaling/normalising method to apply if \code{type = "matrix"} or if \code{type = "cor"}. Can be one of \code{"z-score"}, \code{"Sigmoid"}, \code{"RobustSigmoid"}, or \code{"MinMax"}. Defaults to \code{"z-score"}
+#' @param norm_method \code{character} specifying a rescaling/normalising method to apply if \code{type = "matrix"} or if \code{type = "cor"}. Can be one of \code{"zScore"}, \code{"Sigmoid"}, \code{"RobustSigmoid"}, \code{"MinMax"}, or \code{"MaxAbs"}. Defaults to \code{"zScore"}
 #' @param unit_int \code{Boolean} whether to rescale into unit interval \code{[0,1]} after applying normalisation method. Defaults to \code{FALSE}
 #' @param clust_method \code{character} specifying the hierarchical clustering method to use if \code{type = "matrix"} or if \code{type = "cor"}. Defaults to \code{"average"}
 #' @param cor_method \code{character} specifying the correlation method to use if \code{type = "cor"}. Defaults to \code{"pearson"}
@@ -24,7 +24,7 @@
 #'
 
 plot.feature_calculations <- function(x, type = c("quality", "matrix", "cor", "violin"),
-                                      norm_method = c("z-score", "Sigmoid", "RobustSigmoid", "MinMax"),
+                                      norm_method = c("zScore", "Sigmoid", "RobustSigmoid", "MinMax", "MaxAbs"),
                                       unit_int = FALSE,
                                       clust_method = c("average", "ward.D", "ward.D2", "single", "complete", "mcquitty", "median", "centroid"),
                                       cor_method = c("pearson", "spearman"), feature_names = NULL, ...){
